pub enum ToolCallDecision {
Allowed,
RequiresConfirmation(ToolConfirmationInfo),
Blocked {
reason: String,
},
}Expand description
Decision for a tool call at a given permission level.
Variants
Allowed
The tool call is allowed to execute.
RequiresConfirmation(ToolConfirmationInfo)
The tool call requires user confirmation before it can execute.
Blocked
The tool call is blocked and will not execute.