pub fn requires_confirmation(
permission_level: PermissionLevel,
is_write_operation: bool,
) -> boolExpand description
Return whether an action should require confirmation for a session at the given permission level.
This is primarily used by UI layers to decide whether to show a confirmation prompt before sending a request/tool call.