pub struct HooksSettings {
pub enabled: bool,
pub allowed_programs: Vec<String>,
pub hooks: Vec<HookDefinition>,
pub timeout_ms: u64,
pub max_output_bytes: usize,
}Expand description
Global hooks settings.
These live in AppConfig and are designed to be
compatible with YAML schema evolution (new fields should be
#[serde(default)]).
Fields
enabled: boolGlobal enable switch.
allowed_programs: Vec<String>Allow-list of programs that hooks are permitted to execute.
Safety: empty by default.
hooks: Vec<HookDefinition>Hook definitions.
timeout_ms: u64Maximum time to allow a hook process to run.
max_output_bytes: usizeMaximum number of bytes to retain from stdout/stderr.