pub struct RetryManager { /* private fields */ }Expand description
Retry manager for executing operations with automatic retry
Implementations
Sourceimpl RetryManager
impl RetryManager
Sourcepub fn new(policy: RetryPolicy) -> RetryManager
pub fn new(policy: RetryPolicy) -> RetryManager
Create a new retry manager with the given policy
Sourcepub fn for_api() -> RetryManager
pub fn for_api() -> RetryManager
Create a retry manager with default API policy
Sourcepub fn for_streaming() -> RetryManager
pub fn for_streaming() -> RetryManager
Create a retry manager for streaming operations
Sourcepub fn for_tools() -> RetryManager
pub fn for_tools() -> RetryManager
Create a retry manager for tool execution
Sourcepub fn with_retry_callback(
self,
callback: Box<dyn Fn(RetryEvent) + Sync + Send>,
) -> RetryManager
pub fn with_retry_callback( self, callback: Box<dyn Fn(RetryEvent) + Sync + Send>, ) -> RetryManager
Set a callback to be notified on retry attempts